@@ -12,16 +12,19 @@ class HardwareInfo(BaseModel):
     @staticmethod
     def get_platform() -> str:
         """
-        Get Platform name.
-        :return:
+        Get the platform name.
+
+        :return: the name of the platform
         """
         return platform.system()
 
     @staticmethod
     async def get_cpu_usage(interval: float = 0.1) -> float:
         """
-        Get the CPU percent usage.
-        :return:
+        Get the CPU load percentage usage.
+
+        :param interval: the minimal interval to wait between two consecutive measures
+        :return: the CPU load in %
         """
         return psutil.cpu_percent(interval=interval)
 
@@ -29,6 +32,7 @@ class HardwareInfo(BaseModel):
     async def get_memory_usage() -> float:
         """
         Get the local memory usage.
+
         :return:
         """
         return psutil.virtual_memory()[2]
