@@ -32,16 +32,6 @@ class Location(ABC, BaseModel):
                     logger.exception(f"Failed to request this url: {url}")
                     raise exception
 
-    @classmethod
-    async def get_current_country(cls, url: str = "http://ipinfo.io/json") -> str:
-        """
-        Get the client's country.
-
-        :return: the client's country alpha_iso_2 name.
-        """
-        response = await cls.request(url=url)
-        return response["country"].lower()
-
     @abstractmethod
     @cached()  # type: ignore
     async def get_latest_co2g_kwh(self, today_date: str, hour: str) -> float:
@@ -57,7 +47,7 @@ class Location(ABC, BaseModel):
     @abstractmethod
     async def get_co2g_kwh(self) -> float:
         """
-        Get the Co2g per kwh.
+        Get the CO2g per kwh.
 
         :return: the co2g/kwh value
         """
